@@ -10,6 +10,8 @@ describe 'watcher::db::create_schema' do
         :path        => '/usr/bin',
         :user        => 'watcher',
         :refreshonly => 'true',
+        :try_sleep   => 5,
+        :tries       => 10,
         :logoutput   => 'on_failure',
         :subscribe   => [
           'Anchor[watcher::install::end]',
@@ -33,6 +35,8 @@ describe 'watcher::db::create_schema' do
           :path        => '/usr/bin',
           :user        => 'watcher',
           :refreshonly => 'true',
+          :try_sleep   => 5,
+          :tries       => 10,
           :logoutput   => 'on_failure',
           :subscribe   => [
             'Anchor[watcher::install::end]',
